@@ -1,6 +1,6 @@
 /*
 
-  $Id: compat.c,v 1.9 2005/04/20 22:33:36 pkot Exp $
+  $Id: compat.c,v 1.11 2006/05/22 20:00:43 pkot Exp $
 
   G N O K I I
 
@@ -34,6 +34,17 @@
 #  include <time.h>
 #  define ftime _ftime
 #  define timeb _timeb
+
+int setenv(const char *name, const char *value, int overwrite)
+{
+	return (int)SetEnvironmentVariable(name, value);
+}
+
+void unsetenv(const char *name)
+{
+	SetEnvironmentVariable(name, NULL);
+}
+
 #endif
 
 #ifdef HAVE_SYS_TIME_H
@@ -143,3 +154,27 @@ char *strsep(char **stringp, const char *delim)
 }
 
 #endif
+
+#ifndef HAVE_TIMEGM
+
+#include <time.h>
+#include <stdlib.h>
+
+time_t timegm(struct tm *tm)
+{
+	time_t ret;
+	char *tz;
+
+	tz = getenv("TZ");
+	setenv("TZ", "", 1);
+	tzset();
+	ret = mktime(tm);
+	if (tz)
+		setenv("TZ", tz, 1);
+	else
+		unsetenv("TZ");
+	tzset();
+	return ret;
+}
+
+#endif
