@@ -1,10 +1,10 @@
 /*
 
-  $Id: rlp-common.c,v 1.15 2004/02/20 11:02:25 uid66849 Exp $
+  $Id: rlp-common.c,v 1.16 2005/04/20 20:30:18 pkot Exp $
 
   G N O K I I
 
-  A Linux/Unix toolset and driver for Nokia mobile phones.
+  A Linux/Unix toolset and driver for the mobile phones.
 
   This file is part of gnokii.
 
@@ -22,7 +22,9 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 1999, 2000 Hugh Blemings & Pavel Jank ml.
+  Copyright (C) 1999-2000  Hugh Blemings & Pavel Jank ml.
+  Copyright (C) 2001       Chris Kemp
+  Copyright (C) 2002-2004  BORBELY Zoltan
 
   The development of RLP protocol is sponsored by SuSE CR, s.r.o. (Pavel use
   the SIM card from SuSE for testing purposes).
