@@ -1,6 +1,6 @@
 /*
 
-  $Id: gsm-filetypes.c,v 1.66 2006/01/15 15:13:26 dforsi Exp $
+  $Id: gsm-filetypes.c,v 1.68 2006/06/11 16:39:48 deller Exp $
 
   G N O K I I
 
@@ -1434,7 +1434,7 @@ static int get_next_token(char *src, int delim)
 #define GET_NEXT_TOKEN()	o = get_next_token(line + offset, ';')
 #define STORE_TOKEN(a)		strip_slashes(a, line + offset, sizeof(a) - 1, o - 1)
 
-API gn_error gn_file_phonebook_raw_parse(gn_phonebook_entry *entry, char *line)
+GNOKII_API gn_error gn_file_phonebook_raw_parse(gn_phonebook_entry *entry, char *line)
 {
 	char backline[MAX_INPUT_LINE_LEN];
 	char memory_type_char[3];
@@ -1644,7 +1644,7 @@ endfunc:
 	return error;
 }
 
-API gn_error gn_file_phonebook_raw_write(FILE *f, gn_phonebook_entry *entry, char *memory_type_string)
+GNOKII_API gn_error gn_file_phonebook_raw_write(FILE *f, gn_phonebook_entry *entry, char *memory_type_string)
 {
 	char escaped_name[2 * GN_PHONEBOOK_NAME_MAX_LENGTH];
 	int i;
@@ -1656,6 +1656,9 @@ API gn_error gn_file_phonebook_raw_write(FILE *f, gn_phonebook_entry *entry, cha
 	for (i = 0; i < entry->subentries_count; i++) {
 		switch (entry->subentries[i].entry_type) {
 		case GN_PHONEBOOK_ENTRY_Date:
+			fprintf(f, ";%d;0;0;%04u%02u%02u%02u%02u%02u", GN_PHONEBOOK_ENTRY_Date,
+				entry->subentries[i].data.date.year, entry->subentries[i].data.date.month, entry->subentries[i].data.date.day,
+				entry->subentries[i].data.date.hour, entry->subentries[i].data.date.minute, entry->subentries[i].data.date.second);
 			break;
 		default:
 			add_slashes(escaped_name, entry->subentries[i].data.number, sizeof(escaped_name), strlen(entry->subentries[i].data.number));
@@ -1667,9 +1670,12 @@ API gn_error gn_file_phonebook_raw_write(FILE *f, gn_phonebook_entry *entry, cha
 			break;
 		}
 	}
-	if (entry->memory_type == GN_MT_MC || entry->memory_type == GN_MT_DC || entry->memory_type == GN_MT_RC)
-		fprintf(f, "%d;0;0;%02u.%02u.%04u %02u:%02u:%02u", GN_PHONEBOOK_ENTRY_Date,
-			entry->date.day, entry->date.month, entry->date.year, entry->date.hour, entry->date.minute, entry->date.second);
+	if ((entry->memory_type == GN_MT_MC ||
+		entry->memory_type == GN_MT_DC ||
+		entry->memory_type == GN_MT_RC) &&
+		entry->date.day != 0)
+		fprintf(f, ";%d;0;0;%04u%02u%02u%02u%02u%02u", GN_PHONEBOOK_ENTRY_Date,
+			entry->date.year, entry->date.month, entry->date.day, entry->date.hour, entry->date.minute, entry->date.second);
 	fprintf(f, "\n");
 	return GN_ERR_NONE;
 }
