@@ -1,6 +1,6 @@
 /*
 
-  $Id: misc.c,v 1.111 2006/06/11 16:39:48 deller Exp $
+  $Id: misc.c,v 1.115 2006/08/27 21:18:47 pkot Exp $
 
   G N O K I I
 
@@ -139,16 +139,17 @@ static gn_phone_model models[] = {
 	{"3120b", "RH-50", PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"3200",  "RH-30", 0 },
 	{"3200b", "RH-31", 0 },
-	{"3210",  "NSE-8", PM_SPEEDDIAL | PM_SMS | PM_DTMF | PM_KEYBOARD },
+	{"3210",  "NSE-8", PM_NETMONITOR | PM_SPEEDDIAL | PM_SMS | PM_DTMF | PM_KEYBOARD },
 	{"3210",  "NSE-9", PM_SMS | PM_DTMF | PM_KEYBOARD },
+	{"3220",  "RH-37", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"3285",  "NSD-1A", 0 },
 	{"3300",  "NEM-1", 0 },
 	{"3300",  "NEM-2", 0 },
-	{"3310",  "NHM-5", PM_SPEEDDIAL | PM_SMS | PM_DTMF },
+	{"3310",  "NHM-5", PM_NETMONITOR | PM_SPEEDDIAL | PM_SMS | PM_DTMF },
 	{"3310",  "NHM-5NX", PM_SMS | PM_DTMF },
 	{"3315",  "NHM-5NY", PM_SMS | PM_DTMF },
 	{"3320",  "NPC-1", 0 },
-	{"3330",  "NHM-6", PM_SPEEDDIAL | PM_SMS | PM_DTMF },
+	{"3330",  "NHM-6", PM_NETMONITOR | PM_SPEEDDIAL | PM_SMS | PM_DTMF },
 	{"3350",  "NHM-9", PM_SMS | PM_DTMF },
 	{"3360",  "NPW-6", PM_SMS | PM_DTMF },
 	{"3360",  "NPW-1", PM_SMS | PM_DTMF },
@@ -228,6 +229,7 @@ static gn_phone_model models[] = {
 	{"6230",  "RH12_28_-", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"6230i", "RM72_73_-", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"6250",  "NHM-3", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
+	{"6280",  "RH-78", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"6310",  "NPE-4", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS | PM_KEYBOARD | PM_DTMF },
 	{"6310i", "NPL-1", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS | PM_KEYBOARD | PM_DTMF },
 	{"6340",  "NPM-2", 0 },
@@ -507,7 +509,7 @@ failed:
 	free(lock_file);
 	return NULL;
 #else
-	return NULL;
+	return 1;
 #endif /* WIN32 */
 }
 
