@@ -1,6 +1,6 @@
 /*
 
-  $Id: nokia.c,v 1.40 2005/04/20 20:52:45 pkot Exp $
+  $Id: nokia.c,v 1.42 2006/05/08 17:44:07 deller Exp $
 
   G N O K I I
 
@@ -215,6 +215,13 @@ gn_error pnok_call_divert_incoming(int messagetype, unsigned char *message, int
 	int n;
 	char buf[1024];
 
+	/* the struct is not yet allocated if this is the first unsolicited call divert message */
+	if (!data->call_divert) {
+		data->call_divert = malloc(sizeof(gn_call_divert));
+		if (!data->call_divert) return GN_ERR_MEMORYFULL;
+		memset(data->call_divert, 0, sizeof(*data->call_divert));
+	}
+
 	switch (message[3]) {
 	/* Get call diverts ok */
 	case 0x02:
@@ -516,7 +523,7 @@ gn_error pnok_ringtone_from_raw(gn_ringtone *ringtone, const unsigned char *raw,
 	int i, c, p, current;
 	int rcount, rstart;
 	int lastc, lastp;
-	gn_ringtone_note *note;
+	gn_ringtone_note *note = NULL;
 	int notes[] = {0, 1, 2, 3, 4, 6, 7, 8, 9, 10, 11, 12};
 	int dct4, base;
 
