@@ -1,6 +1,6 @@
 /*
 
-  $Id: vcal.c,v 1.10 2006/03/11 15:30:46 pkot Exp $
+  $Id: vcal.c,v 1.12 2006/06/11 16:39:48 deller Exp $
 
   G N O K I I
 
@@ -71,7 +71,7 @@ static inline const char *get_prodid()
 /*
 	ICALENDAR Reading functions
  */
-API int gn_calnote2ical(FILE *f, gn_calnote *calnote)
+GNOKII_API int gn_calnote2ical(FILE *f, gn_calnote *calnote)
 {
 #ifdef HAVE_LIBICAL
 #  define MAX_PROP_INDEX 5
@@ -123,10 +123,13 @@ API int gn_calnote2ical(FILE *f, gn_calnote *calnote)
 	/* TODO: should the strings be configurable? */
 	switch(calnote->type) {
 	case GN_CALNOTE_MEMO:
-	case GN_CALNOTE_REMINDER:
 		properties[iprop++] = icalproperty_new_categories("MISCELLANEOUS");
 		properties[iprop++] = icalproperty_new_summary(calnote->text);
 		break;
+	case GN_CALNOTE_REMINDER:
+		properties[iprop++] = icalproperty_new_categories("REMINDER");
+		properties[iprop++] = icalproperty_new_summary(calnote->text);
+		break;
 	case GN_CALNOTE_CALL:
 		properties[iprop++] = icalproperty_new_categories("PHONE CALL");
 		properties[iprop++] = icalproperty_new_summary(calnote->phone_number);
@@ -202,9 +205,11 @@ API int gn_calnote2ical(FILE *f, gn_calnote *calnote)
 	fprintf(f, "CATEGORIES:");
 	switch (calnote->type) {
 	case GN_CALNOTE_MEMO:
-	case GN_CALNOTE_REMINDER:
 		fprintf(f, "MISCELLANEOUS\r\n");
 		break;
+	case GN_CALNOTE_REMINDER:
+		fprintf(f, "REMINDER\r\n");
+		break;
 	case GN_CALNOTE_CALL: 
 		fprintf(f, "PHONE CALL\r\n");
 		fprintf(f, "SUMMARY:%s\r\n", calnote->phone_number);
@@ -233,7 +238,9 @@ API int gn_calnote2ical(FILE *f, gn_calnote *calnote)
 			calnote->end_time.minute, calnote->end_time.second); 
 	}
 	if (calnote->alarm.enabled) {
-		fprintf(f, "AALARM:%04d%02d%02dT%02d%02d%02d\r\n", calnote->alarm.timestamp.year, 
+		fprintf(f, "%sALARM:%04d%02d%02dT%02d%02d%02d\r\n",
+		(calnote->alarm.tone ? "A" : "D"),
+		calnote->alarm.timestamp.year, 
 		calnote->alarm.timestamp.month, calnote->alarm.timestamp.day, calnote->alarm.timestamp.hour, 
 		calnote->alarm.timestamp.minute, calnote->alarm.timestamp.second); 
 	} 
@@ -275,12 +282,14 @@ static inline gn_calnote_type str2calnote_type(const char *str)
 		return GN_CALNOTE_MEETING;
 	} else if (!strncasecmp("ANNIVERSARY", str, 11)) {
 		return GN_CALNOTE_BIRTHDAY;
+	} else if (!strncasecmp("MISCELLANOUS", str, 12)) {
+		return GN_CALNOTE_MEMO;
 	}
 	return GN_CALNOTE_REMINDER;
 }
 
 /* read a vcalendar event given by id from file f and store the data in calnote */
-API int gn_ical2calnote(FILE *f, gn_calnote *calnote, int id)
+GNOKII_API int gn_ical2calnote(FILE *f, gn_calnote *calnote, int id)
 {
 	int retval = GN_ERR_FAILED;
 #ifdef HAVE_LIBICAL
@@ -419,7 +428,7 @@ API int gn_ical2calnote(FILE *f, gn_calnote *calnote, int id)
 	return retval;
 }
 
-API int gn_todo2ical(FILE *f, gn_todo *ctodo)
+GNOKII_API int gn_todo2ical(FILE *f, gn_todo *ctodo)
 {
 #ifdef HAVE_LIBICAL
 	icalcomponent *pIcal = NULL;
@@ -469,7 +478,7 @@ API int gn_todo2ical(FILE *f, gn_todo *ctodo)
 }
 
 /* read the entry identified by id from the vcal file f and write it to the phone */
-API int gn_ical2todo(FILE *f, gn_todo *ctodo, int id)
+GNOKII_API int gn_ical2todo(FILE *f, gn_todo *ctodo, int id)
 {
 #ifdef HAVE_LIBICAL
 	icalparser *parser = NULL;
