@@ -1,6 +1,6 @@
 /*
 
-  $Id: nk6510.h,v 1.28 2006/01/23 23:21:57 bozo Exp $
+  $Id: nk6510.h,v 1.30 2006/04/11 21:31:42 pkot Exp $
 
   G N O K I I
 
@@ -119,8 +119,10 @@ typedef enum {
 #define NK6510_SUBCAL_DEL_NOTE_RESP	0x0c	/* Dletete note response */
 #define NK6510_SUBCAL_NOTE_RCVD		0x1a	/* Received note */
 #define NK6510_SUBCAL_FREEPOS_RCVD	0x32	/* Received first free position */
-#define NK6510_SUBCAL_INFO_RCVD		0x3b	/* Received calendar summary*/
+#define NK6510_SUBCAL_INFO_RCVD		0x3b	/* Received calendar summary */
 #define NK6510_SUBCAL_NOTE2_RCVD	0x7e	/* Received note (with more detailes) */
+#define NK6510_SUBCAL_ADD_NOTE_RESP	0x66	/* Add calendar note response */
+
 /* Calendar note types */
 #define NK6510_NOTE_REMINDER		0x00	/* Reminder */
 #define NK6510_NOTE_MEETING		0x01	/* Meeting */
@@ -194,4 +196,6 @@ typedef enum {
 
 #define	NK6510_RINGTONE_USERDEF_LOCATION	231
 
+#define NK6510_FILE_ID_LENGTH 6
+
 #endif  /* _gnokii_phones_nk6510_h */
