@@ -17,16 +17,16 @@
 
 #define NOKIA_VENDOR_ID		0x0421
 
-#define NOKIA7600_PRODUCT_ID	0x0400 7600
-#define NOKIA6650_PRODUCT_ID	0x0401 6650
-#define NOKIA6255_PRODUCT_ID	0x0402 6255
-#define NOKIA6651_PRODUCT_ID	0x040E 6651
-#define NOKIA6230_PRODUCT_ID	0x040F 6230
-#define NOKIA6170_PRODUCT_ID	0x0416 6170
-#define NOKIA7270_PRODUCT_ID	0x0417 7270
-#define NOKIA7710_PRODUCT_ID	0x041C 7710
-#define NOKIA3230_PRODUCT_ID	0x0421 3230
-#define NOKIA6230i_PRODUCT_ID	0x0428 6230i
+#define NOKIA7600_PRODUCT_ID	0x0400
+#define NOKIA6650_PRODUCT_ID	0x0401
+#define NOKIA6255_PRODUCT_ID	0x0402
+#define NOKIA6651_PRODUCT_ID	0x040E
+#define NOKIA6230_PRODUCT_ID	0x040F
+#define NOKIA6170_PRODUCT_ID	0x0416
+#define NOKIA7270_PRODUCT_ID	0x0417
+#define NOKIA7710_PRODUCT_ID	0x041C
+#define NOKIA3230_PRODUCT_ID	0x0421
+#define NOKIA6230i_PRODUCT_ID	0x0428
 #define NOKIA6265_PRODUCT_ID	0x0437
 
 #define NOKIA_AT_PORT	0x82
