@@ -1,6 +1,6 @@
 /*
 
-  $Id: mysql.c,v 1.27 2006/01/21 00:25:30 ja Exp $
+  $Id: mysql.c,v 1.30 2006/08/10 19:10:14 pkot Exp $
 
   S M S D
 
@@ -29,6 +29,7 @@
   
 */
 
+#include <unistd.h>
 #include <string.h>
 #include <stdlib.h>
 #include <glib.h>
@@ -36,18 +37,19 @@
 #include "smsd.h"
 #include "gnokii.h"
 #include "compat.h"
+#include "utils.h"
 
 static MYSQL mysqlIn;
 static MYSQL mysqlOut;
 
-void DB_Bye (void)
+GNOKII_API void DB_Bye (void)
 {
   mysql_close (&mysqlIn);
   mysql_close (&mysqlOut);
 }
 
 
-gint DB_ConnectInbox (DBConfig connect)
+GNOKII_API gint DB_ConnectInbox (DBConfig connect)
 {
   mysql_init (&mysqlIn);
   if (!mysql_real_connect (&mysqlIn,
@@ -66,7 +68,7 @@ gint DB_ConnectInbox (DBConfig connect)
 }
 
 
-gint DB_ConnectOutbox (DBConfig connect)
+GNOKII_API gint DB_ConnectOutbox (DBConfig connect)
 {
   mysql_init (&mysqlOut);
   if (!mysql_real_connect (&mysqlOut,
@@ -85,11 +87,10 @@ gint DB_ConnectOutbox (DBConfig connect)
 }
 
 
-gint DB_InsertSMS (const gn_sms * const data, const gchar * const phone)
+GNOKII_API gint DB_InsertSMS (const gn_sms * const data, const gchar * const phone)
 {
   GString *buf, *phnStr;
   gchar *text;
-  gint l;
 
 
   if (phone[0] == '\0')
@@ -131,7 +132,7 @@ gint DB_InsertSMS (const gn_sms * const data, const gchar * const phone)
 }
 
 
-void DB_Look (const gchar * const phone)
+GNOKII_API void DB_Look (const gchar * const phone)
 {
   GString *buf, *phnStr;
   MYSQL_RES *res1;
