@@ -1,6 +1,6 @@
 /*
 
-  $Id: smsd.c,v 1.51 2006/05/10 12:47:57 ja Exp $
+  $Id: smsd.c,v 1.54 2006/08/10 21:09:16 pkot Exp $
 
   S M S D
 
@@ -81,27 +81,6 @@ static pthread_t db_monitor_th;
 pthread_mutex_t db_monitorMutex;
 static volatile bool db_monitor;
 
-/* Escapes ' and \ with \. */
-/* Returned value needs to be free with g_free(). */
-gchar *strEscape (const gchar *const s)
-{
-  GString *str = g_string_new (s);
-  register gint i = 0;
-  gchar *ret;
-  
-  while (str->str[i] != '\0')
-  {
-    if (str->str[i] == '\\' || str->str[i] == '\'')
-      g_string_insert_c (str, i++, '\\');
-    i++;
-  }
-  
-  ret = str->str;
-  g_string_free (str, FALSE);
-  
-  return (ret);
-}
-
 
 gint LoadDB (void)
 {
@@ -125,35 +104,35 @@ gint LoadDB (void)
   DB_Bye = dlsym(handle, "DB_Bye");
   if ((error = dlerror ()) != NULL)
   {
-    g_print (error);
+    g_print ("%s\n", error);
     return (2);
   }
 
   DB_ConnectInbox = dlsym(handle, "DB_ConnectInbox");
   if ((error = dlerror ()) != NULL)
   {
-    g_print (error);
+    g_print ("%s\n", error);
     return (2);
   }
 
   DB_ConnectOutbox = dlsym(handle, "DB_ConnectOutbox");
   if ((error = dlerror ()) != NULL)
   {
-    g_print (error);
+    g_print ("%s\n", error);
     return (2);
   }
   
   DB_InsertSMS = dlsym(handle, "DB_InsertSMS");
   if ((error = dlerror ()) != NULL)
   {
-    g_print (error);
+    g_print ("%s\n", error);
     return (2);
   }
   
   DB_Look = dlsym(handle, "DB_Look");
   if ((error = dlerror ()) != NULL)
   {
-    g_print (error);
+    g_print ("%s\n", error);
     return (2);
   }
   
@@ -386,7 +365,7 @@ static void *SendSMS (void *a)
 }
 
 
-gint WriteSMS (gn_sms *sms)
+GNOKII_API gint WriteSMS (gn_sms *sms)
 {
   gn_error error;
   PhoneEvent *e = (PhoneEvent *) g_malloc (sizeof (PhoneEvent));
