@@ -1,6 +1,6 @@
 /*
 
-  $Id: smsd.h,v 1.16 2006/02/08 22:15:46 ja Exp $
+  $Id: smsd.h,v 1.18 2006/08/10 21:09:16 pkot Exp $
 
   S M S D
 
@@ -57,8 +57,7 @@ typedef struct {
   gchar *schema;
 } DBConfig;
 
-extern gchar *strEscape (const gchar *const);
 extern SmsdConfig smsdConfig;
-extern gint WriteSMS (gn_sms *);
+GNOKII_API gint WriteSMS (gn_sms *);
 
 #endif
