@@ -1,10 +1,10 @@
 /*
 
-  $Id: mgnokiidev.c,v 1.22 2003/10/14 21:39:24 bozo Exp $
+  $Id: mgnokiidev.c,v 1.24 2005/04/20 20:25:31 pkot Exp $
 
   G N O K I I
 
-  A Linux/Unix toolset and driver for Nokia mobile phones.
+  A Linux/Unix toolset and driver for the mobile phones.
 
   This file is part of gnokii.
 
@@ -22,7 +22,9 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 2002 Pawe Kot
+  Copyright (C) 1999-2000  Hugh Blemings, Pavel Janik ml.
+  Copyright (C) 2000-2002  Pawel Kot
+  Copyright (C) 2002-2003  BORBELY Zoltan
 
   The code is based on the skeleton from W. Richard Stevens' "UNIX Network Programming",
   Volume 1, Second Edition.
@@ -45,6 +47,11 @@
 #  define	__BSD_VISIBLE	1
 #endif
 
+/* See common/data/virtmodem.c for explanation */
+#ifdef	__NetBSD__
+#  include <sys/types.h>
+#endif
+
 /* See common/data/virtmodem.c for explanation */
 #define _XOPEN_SOURCE 500
 
