@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_logos.c,v 1.41 2006/05/08 19:20:07 deller Exp $
+  $Id: xgnokii_logos.c,v 1.43 2006/08/16 12:22:41 dforsi Exp $
    
   X G N O K I I
 
@@ -970,6 +970,8 @@ void GetNetworkInfoEvent(GtkWidget * widget)
 		gtk_label_set_text(GTK_LABEL(errorDialog.text), buf);
 		gtk_widget_show(errorDialog.dialog);
 		g_free(buf);
+		/* after the error network_code is undefined but later code won't know */
+		networkInfo.network_code[0] = '\0';
 	}
 
 	/* set new operator name to combo */
@@ -1824,7 +1826,7 @@ void GUI_ShowLogosWindow(void)
 	/* Call to reset Startup logo size */
 	LogoTypeEvent(GUI_LogosWindow);
 	g_print("width: %i, height: %i\n", bitmap.width, bitmap.height);
-	gtk_widget_show(GUI_LogosWindow);
+	gtk_window_present(GTK_WINDOW(GUI_LogosWindow));
 
 	if (!previewAvailable && showPreviewErrorDialog) {
 		gchar *buf = g_strdup(_("Load preview pixmap error, feature disabled."));
